@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 # GNU Solfege - free ear training software
-# Copyright (C) 2009, 2010  Tom Cato Amundsen
+# Copyright (C) 2009, 2010, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@ import logging
 import gtk
 
 import solfege
-from solfege import cfg
 from solfege import frontpage
 from solfege import gu
 from solfege import lessonfile
@@ -122,7 +121,7 @@ class SelectWinBase(gtk.ScrolledWindow):
         # ubuntu 10.04 and +4 on MS Windows XP.
         h = self.g_box.size_request()[1] + 4
         if h > gtk.gdk.screen_height() * 0.8:
-            h = gtk.gdk.screen_height() *0.8
+            h = int(gtk.gdk.screen_height() *0.8)
         self.set_size_request(w, h if h > self.m_min_height else self.m_min_height)
         # Then we check if we have to move the app window higher up on the
         # screen so that the whole window is visible.
@@ -166,7 +165,8 @@ class ExerciseView(SelectWinBase):
         if len(page[0]) > 0 and isinstance(page[0][0], frontpage.LinkList):
             count = 0
             for p in page[0]:
-                count += len(page[0][0])
+                if len(p):
+                    count += len(p[0])
             if count > 80:
                 do_sg = False
         for column in page:
@@ -294,7 +294,7 @@ class ExerciseView(SelectWinBase):
         only_tests - True if we should only return exercises that have
                      tests
         """
-        logging.debug("search: '%s'" % substring)
+        logging.debug("search: '%s'", substring)
         match_func = {
             False: lambda filename: substring in _no_xgettext(lessonfile.infocache.get(filename, 'title')).lower(),
             True: lambda filename: substring in lessonfile.infocache.get(filename, 'title').lower()
@@ -333,7 +333,7 @@ class FrontPage(ExerciseView):
         self.g_searchentry.grab_focus()
     def on_search(self, *button):
         search_for = self.g_searchentry.get_text().lower()
-        logging.debug("FrontPage.on_search '%s'" % search_for)
+        logging.debug("FrontPage.on_search '%s'", search_for)
         page = self._search(search_for, False, False)
         page_C = self._search(search_for, True, False)
         page_C.m_name = _('Search untranslated lesson titles')
