@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008 Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2007, 2008, 2011 Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -94,7 +94,7 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
-        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_music_displayer = mpd.MusicDisplayer()
         self.practise_box.pack_start(self.g_music_displayer, False)
         self.g_bb = QuestionNameButtonTable(self.m_t.m_exname)
         self.practise_box.pack_start(self.g_bb, False)
@@ -184,7 +184,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_music_displayer.hide()
     def give_up(self, _o=None):
         if self.m_t.q_status == self.QSTATUS_WRONG:
-            self.g_flashbar.push(_("The answer is: %s") % self.m_t.m_P.get_name())
+            self.g_flashbar.push(_("The answer is: {answer}"), answer=self.m_t.m_P.get_name())
             self.m_t.give_up()
             self.std_buttons_give_up()
             if self.m_t.m_P.header.have_music_displayer:
