@@ -1,5 +1,5 @@
 # GNU Solfege - free ear training software
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007, 2008, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,27 +26,40 @@ the mpd module:
 """
 
 
-LOWEST_NOTENAME="c,,,,"
-HIGHEST_NOTENAME="g''''''"
+LOWEST_NOTENAME = "c,,,,"
+HIGHEST_NOTENAME = "g''''''"
 
 from solfege.mpd.duration import Duration
 from solfege.mpd.musicalpitch import MusicalPitch, InvalidNotenameException
 from solfege.mpd.interval import Interval
 from solfege.mpd.mpdutils import notename_to_int, int_to_notename, int_to_user_notename
+from solfege.mpd.parser import parse_to_score_object
 from solfege.mpd.rat import Rat
 from solfege.mpd.track import Track, PercussionTrack
 from solfege.mpd._exceptions import MpdException
 from solfege.mpd.performer import score_to_tracks
+try:
+    # solfege.app_running is set in solfege/startup.py, but will be
+    # unset if run from some of the build scripts. This way we can
+    # build without having a X display.
+    import solfege
+    if solfege.app_running:
+        from solfege.mpd.rhythmwidget import RhythmWidget, RhythmWidgetController
+        from solfege.mpd.musicdisplayer import MusicDisplayer
+except AttributeError:
+    pass
+finally:
+    del solfege
 
 def music_to_tracklist(music, start=None, end=None):
     """
     return a list of tracks, where track[0] use only channel 0,
     track[1] only use channel 1 etc.
     """
-    return score_to_tracks(parser.parse_to_score_object(music), start, end)
+    return score_to_tracks(parse_to_score_object(music), start, end)
 
 def music_to_track(music, start=None, end=None):
-    tracklist = score_to_tracks(parser.parse_to_score_object(music), start, end)
+    tracklist = score_to_tracks(parse_to_score_object(music), start, end)
     track = tracklist[0]
     for x in range(1, len(tracklist)):
         track.merge_with(tracklist[x])
